# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'HostPoolRegistrationInfo',
]

@pulumi.output_type
class HostPoolRegistrationInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expirationDate":
            suggest = "expiration_date"
        elif key == "resetToken":
            suggest = "reset_token"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in HostPoolRegistrationInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        HostPoolRegistrationInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        HostPoolRegistrationInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expiration_date: str,
                 reset_token: Optional[bool] = None,
                 token: Optional[str] = None):
        """
        :param str expiration_date: A valid `RFC3339Time` for the expiration of the token.
        :param str token: The registration token generated by the Virtual Desktop Host Pool.
        """
        pulumi.set(__self__, "expiration_date", expiration_date)
        if reset_token is not None:
            pulumi.set(__self__, "reset_token", reset_token)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> str:
        """
        A valid `RFC3339Time` for the expiration of the token.
        """
        return pulumi.get(self, "expiration_date")

    @property
    @pulumi.getter(name="resetToken")
    def reset_token(self) -> Optional[bool]:
        return pulumi.get(self, "reset_token")

    @property
    @pulumi.getter
    def token(self) -> Optional[str]:
        """
        The registration token generated by the Virtual Desktop Host Pool.
        """
        return pulumi.get(self, "token")


